| git_pull | R Documentation |
This will pull any updates from the 'origin' remote for every branch.
This should be run before making a commit (as is done by wrapper git()) in
order to avoid conflicts arising if somebody else has made changes
on the same branch. If this happens, merge conflicts are raised in the usual
way and git_add() will show you what needs resolving.
git_pull()
To setup an 'origin' remote, use git_remote(). Credentials are handled
in the same way as git_push(), see ?git_push for details.
Invisible NULL
git_push, git_remote
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.